# Streamlit - Antv charts

A streamlit component to implement antv charts

## Installation

```
pip install streamlit-antv
```

## Usage

Refer to the following files for example usage
- [g6](g6/__init__.py)

## IN PROGRESS

- g6 submit
  - see toolbar button in demo
- pass in function, how to identify as function (suffix or prefix as fn?)
  - see `__init__.py`

```
"onLayoutEnd": json.dumps(['__#fn#__', 'alert("loaded chart with key=" + window.stProps.key());'])
```
## TBD

- g2
- g2plot

## NOTES

https://g6.antv.vision/en/docs/manual/FAQ/vite-support
